<?php
/**
 * VW Charity NGO Theme Customizer
 *
 * @package VW Charity NGO
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function vw_charity_ngo_custom_controls() {

    load_template( trailingslashit( get_template_directory() ) . '/inc/custom-controls.php' );
}
add_action( 'customize_register', 'vw_charity_ngo_custom_controls' );

function vw_charity_ngo_customize_register( $wp_customize ) {

	load_template( trailingslashit( get_template_directory() ) . '/inc/icon-picker.php' );

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial( 'blogname', array( 
		'selector' => '.logo .site-title a', 
	 	'render_callback' => 'vw_charity_ngo_customize_partial_blogname', 
	)); 

	$wp_customize->selective_refresh->add_partial( 'blogdescription', array( 
		'selector' => 'p.site-description', 
		'render_callback' => 'vw_charity_ngo_customize_partial_blogdescription', 
	));

	//add home page setting pannel
	$VWCharityNGOParentPanel = new VW_Charity_NGO_WP_Customize_Panel( $wp_customize, 'vw_charity_ngo_panel_id', array(
		'capability' => 'edit_theme_options',
		'theme_supports' => '',
		'title' => esc_html__( 'VW Settings', 'vw-charity-ngo' ),
		'priority' => 10,
	));

	$wp_customize->add_section( 'vw_charity_ngo_left_right', array(
    	'title'      => esc_html__( 'General Settings', 'vw-charity-ngo' ),
		'priority'   => 30,
		'panel' => 'vw_charity_ngo_panel_id'
	) );

	$wp_customize->add_setting('vw_charity_ngo_width_option',array(
        'default' => 'Full Width',
        'sanitize_callback' => 'vw_charity_ngo_sanitize_choices'
	));
	$wp_customize->add_control(new VW_Charity_NGO_Image_Radio_Control($wp_customize, 'vw_charity_ngo_width_option', array(
        'type' => 'select',
        'label' => __('Width Layouts','vw-charity-ngo'),
        'description' => __('Here you can change the width layout of Website.','vw-charity-ngo'),
        'section' => 'vw_charity_ngo_left_right',
        'choices' => array(
            'Full Width' => esc_url(get_template_directory_uri()).'/images/full-width.png',
            'Wide Width' => esc_url(get_template_directory_uri()).'/images/wide-width.png',
            'Boxed' => esc_url(get_template_directory_uri()).'/images/boxed-width.png',
    ))));

	// Add Settings and Controls for Layout
	$wp_customize->add_setting('vw_charity_ngo_theme_options',array(
        'default' => 'Right Sidebar',
        'sanitize_callback' => 'vw_charity_ngo_sanitize_choices'	        
	) );
	$wp_customize->add_control('vw_charity_ngo_theme_options', array(
        'type' => 'select',
        'label' => __('Post Sidebar Layout','vw-charity-ngo'),
        'description' => __('Here you can change the sidebar layout for posts. ','vw-charity-ngo'),
        'section' => 'vw_charity_ngo_left_right',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','vw-charity-ngo'),
            'Right Sidebar' => __('Right Sidebar','vw-charity-ngo'),
            'One Column' => __('One Column','vw-charity-ngo'),
            'Three Columns' => __('Three Columns','vw-charity-ngo'),
            'Four Columns' => __('Four Columns','vw-charity-ngo'),
            'Grid Layout' => __('Grid Layout','vw-charity-ngo')
        ),
	));

	$wp_customize->add_setting('vw_charity_ngo_page_layout',array(
        'default' => 'One Column',
        'sanitize_callback' => 'vw_charity_ngo_sanitize_choices'
	));
	$wp_customize->add_control('vw_charity_ngo_page_layout',array(
        'type' => 'select',
        'label' => __('Page Sidebar Layout','vw-charity-ngo'),
        'description' => __('Here you can change the sidebar layout for pages. ','vw-charity-ngo'),
        'section' => 'vw_charity_ngo_left_right',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','vw-charity-ngo'),
            'Right Sidebar' => __('Right Sidebar','vw-charity-ngo'),
            'One Column' => __('One Column','vw-charity-ngo')
        ),
	) );

	//Pre-Loader
	$wp_customize->add_setting( 'vw_charity_ngo_loader_enable',array(
        'default' => 0,
        'transport' => 'refresh',
        'sanitize_callback' => 'vw_charity_ngo_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Charity_NGO_Toggle_Switch_Custom_Control( $wp_customize, 'vw_charity_ngo_loader_enable',array(
        'label' => esc_html__( 'Pre-Loader','vw-charity-ngo' ),
        'section' => 'vw_charity_ngo_left_right'
    )));

	$wp_customize->add_setting('vw_charity_ngo_preloader_bg_color', array(
		'default'           => '#f75e61',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'vw_charity_ngo_preloader_bg_color', array(
		'label'    => __('Pre-Loader Background Color', 'vw-charity-ngo'),
		'section'  => 'vw_charity_ngo_left_right',
	)));

	$wp_customize->add_setting('vw_charity_ngo_preloader_border_color', array(
		'default'           => '#ffffff',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'vw_charity_ngo_preloader_border_color', array(
		'label'    => __('Pre-Loader Border Color', 'vw-charity-ngo'),
		'section'  => 'vw_charity_ngo_left_right',
	)));

	//Topbar section
	$wp_customize->add_section('vw_charity_ngo_topbar',array(
		'title'	=> __('Topbar Section','vw-charity-ngo'),
		'description'	=> __('Add TopBar Content here','vw-charity-ngo'),
		'priority'	=> null,
		'panel' => 'vw_charity_ngo_panel_id',
	));

	$wp_customize->add_setting( 'vw_charity_ngo_topbar_hide_show',
       array(
      'default' => 0,
      'transport' => 'refresh',
      'sanitize_callback' => 'vw_charity_ngo_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Charity_NGO_Toggle_Switch_Custom_Control( $wp_customize, 'vw_charity_ngo_topbar_hide_show',
       array(
      'label' => esc_html__( 'Show / Hide Topbar','vw-charity-ngo' ),
      'section' => 'vw_charity_ngo_topbar'
    )));

    $wp_customize->add_setting('vw_charity_ngo_topbar_padding_top_bottom',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_charity_ngo_topbar_padding_top_bottom',array(
		'label'	=> __('Topbar Padding Top Bottom','vw-charity-ngo'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-charity-ngo'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-charity-ngo' ),
        ),
		'section'=> 'vw_charity_ngo_topbar',
		'type'=> 'text'
	));

    //Sticky Header
	$wp_customize->add_setting( 'vw_charity_ngo_sticky_header',array(
        'default' => 0,
        'transport' => 'refresh',
        'sanitize_callback' => 'vw_charity_ngo_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Charity_NGO_Toggle_Switch_Custom_Control( $wp_customize, 'vw_charity_ngo_sticky_header',array(
        'label' => esc_html__( 'Sticky Header','vw-charity-ngo' ),
        'section' => 'vw_charity_ngo_topbar'
    )));

    $wp_customize->add_setting('vw_charity_ngo_sticky_header_padding',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_charity_ngo_sticky_header_padding',array(
		'label'	=> __('Sticky Header Padding','vw-charity-ngo'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-charity-ngo'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-charity-ngo' ),
        ),
		'section'=> 'vw_charity_ngo_topbar',
		'type'=> 'text'
	));

    //Selective Refresh
	$wp_customize->selective_refresh->add_partial('vw_charity_ngo_address',array( 
		'selector' => '#top-bar span', 
		'render_callback' => 'vw_charity_ngo_customize_partial_vw_charity_ngo_address', 
	));

    $wp_customize->add_setting('vw_charity_ngo_topbar_location_icon',array(
		'default'	=> 'fas fa-map-marker-alt',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new VW_Charity_NGO_Fontawesome_Icon_Chooser(
        $wp_customize,'vw_charity_ngo_topbar_location_icon',array(
		'label'	=> __('Add Location Icon','vw-charity-ngo'),
		'transport' => 'refresh',
		'section'	=> 'vw_charity_ngo_topbar',
		'setting'	=> 'vw_charity_ngo_topbar_location_icon',
		'type'		=> 'icon'
	)));
	
	$wp_customize->add_setting('vw_charity_ngo_address',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('vw_charity_ngo_address',array(
		'label'	=> __('Add Location','vw-charity-ngo'),
		'section'	=> 'vw_charity_ngo_topbar',
		'setting'	=> 'vw_charity_ngo_address',
		'type'		=> 'text'
	));

	$wp_customize->add_setting('vw_charity_ngo_contact_no_icon',array(
		'default'	=> 'fas fa-mobile-alt',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new VW_Charity_NGO_Fontawesome_Icon_Chooser(
        $wp_customize,'vw_charity_ngo_contact_no_icon',array(
		'label'	=> __('Add Contact Icon','vw-charity-ngo'),
		'transport' => 'refresh',
		'section'	=> 'vw_charity_ngo_topbar',
		'setting'	=> 'vw_charity_ngo_contact_no_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting('vw_charity_ngo_contact',array(
		'default'	=> '',
		'sanitize_callback'	=> 'vw_charity_ngo_sanitize_phone_number'
	));	
	$wp_customize->add_control('vw_charity_ngo_contact',array(
		'label'	=> __('Add Contact Details','vw-charity-ngo'),
		'section'	=> 'vw_charity_ngo_topbar',
		'setting'	=> 'vw_charity_ngo_contact',
		'type'		=> 'text'
	));	

	$wp_customize->add_setting('vw_charity_ngo_email_address_icon',array(
		'default'	=> 'fa fa-envelope',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new VW_Charity_NGO_Fontawesome_Icon_Chooser(
        $wp_customize,'vw_charity_ngo_email_address_icon',array(
		'label'	=> __('Add Email Icon','vw-charity-ngo'),
		'transport' => 'refresh',
		'section'	=> 'vw_charity_ngo_topbar',
		'setting'	=> 'vw_charity_ngo_email_address_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting('vw_charity_ngo_email',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_email'
	));	
	$wp_customize->add_control('vw_charity_ngo_email',array(
		'label'	=> __('Add Email Address','vw-charity-ngo'),
		'section'	=> 'vw_charity_ngo_topbar',
		'setting'	=> 'vw_charity_ngo_email',
		'type'		=> 'text'
	));

	$wp_customize->add_setting('vw_charity_ngo_text',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('vw_charity_ngo_text',array(
		'label'	=> __('Button Text','vw-charity-ngo'),
		'section'	=> 'vw_charity_ngo_topbar',
		'setting'	=> 'vw_charity_ngo_text',
		'type'		=> 'text'
	));

	$wp_customize->add_setting('vw_charity_ngo_link',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('vw_charity_ngo_link',array(
		'label'	=> __('Button Link','vw-charity-ngo'),
		'section'	=> 'vw_charity_ngo_topbar',
		'setting'	=> 'vw_charity_ngo_link',
		'type'		=> 'text'
	));

	//Slider
	$wp_customize->add_section( 'vw_charity_ngo_slidersettings' , array(
    	'title'      => __( 'Slider Settings', 'vw-charity-ngo' ),
		'priority'   => null,
		'panel' => 'vw_charity_ngo_panel_id'
	) );

	$wp_customize->add_setting( 'vw_charity_ngo_slider_hide_show',
       array(
      'default' => 0,
      'transport' => 'refresh',
      'sanitize_callback' => 'vw_charity_ngo_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Charity_NGO_Toggle_Switch_Custom_Control( $wp_customize, 'vw_charity_ngo_slider_hide_show',
       array(
      'label' => esc_html__( 'Show / Hide Slider','vw-charity-ngo' ),
      'section' => 'vw_charity_ngo_slidersettings'
    )));

    //Selective Refresh
    $wp_customize->selective_refresh->add_partial('vw_charity_ngo_slider_hide_show',array(
		'selector'        => '#slider .inner_carousel h1',
		'render_callback' => 'vw_charity_ngo_customize_partial_vw_charity_ngo_slider_hide_show',
	));

	for ( $count = 1; $count <= 4; $count++ ) {
		// Add color scheme setting and control.
		$wp_customize->add_setting( 'vw_charity_ngo_slider_page' . $count, array(
			'default'           => '',
			'sanitize_callback' => 'vw_charity_ngo_sanitize_dropdown_pages'
		) );
		$wp_customize->add_control( 'vw_charity_ngo_slider_page' . $count, array(
			'label'    => __( 'Select Slide Image Page', 'vw-charity-ngo' ),
			'description' => __('Slider image size (1500 x 765)','vw-charity-ngo'),
			'section'  => 'vw_charity_ngo_slidersettings',
			'type'     => 'dropdown-pages'
		) );
	}

	$wp_customize->add_setting('vw_charity_ngo_slider_button_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_charity_ngo_slider_button_text',array(
		'label'	=> __('Add Slider Button Text','vw-charity-ngo'),
		'input_attrs' => array(
            'placeholder' => __( 'READ MORE', 'vw-charity-ngo' ),
        ),
		'section'=> 'vw_charity_ngo_slidersettings',
		'type'=> 'text'
	));

	//content layout
	$wp_customize->add_setting('vw_charity_ngo_slider_content_option',array(
        'default' => 'Left',
        'sanitize_callback' => 'vw_charity_ngo_sanitize_choices'
	));
	$wp_customize->add_control(new VW_Charity_NGO_Image_Radio_Control($wp_customize, 'vw_charity_ngo_slider_content_option', array(
        'type' => 'select',
        'label' => __('Slider Content Layouts','vw-charity-ngo'),
        'section' => 'vw_charity_ngo_slidersettings',
        'choices' => array(
            'Left' => esc_url(get_template_directory_uri()).'/images/slider-content1.png',
            'Center' => esc_url(get_template_directory_uri()).'/images/slider-content2.png',
            'Right' => esc_url(get_template_directory_uri()).'/images/slider-content3.png',
    ))));

    //Slider excerpt
	$wp_customize->add_setting( 'vw_charity_ngo_slider_excerpt_number', array(
		'default'              => 30,
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'vw_charity_ngo_sanitize_number_range'
	) );
	$wp_customize->add_control( 'vw_charity_ngo_slider_excerpt_number', array(
		'label'       => esc_html__( 'Slider Excerpt length','vw-charity-ngo' ),
		'section'     => 'vw_charity_ngo_slidersettings',
		'type'        => 'range',
		'settings'    => 'vw_charity_ngo_slider_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	//Opacity
	$wp_customize->add_setting('vw_charity_ngo_slider_opacity_color',array(
      'default'              => 0.5,
      'sanitize_callback' => 'vw_charity_ngo_sanitize_choices'
	));

	$wp_customize->add_control( 'vw_charity_ngo_slider_opacity_color', array(
	'label'       => esc_html__( 'Slider Image Opacity','vw-charity-ngo' ),
	'section'     => 'vw_charity_ngo_slidersettings',
	'type'        => 'select',
	'settings'    => 'vw_charity_ngo_slider_opacity_color',
	'choices' => array(
      '0' =>  esc_attr('0','vw-charity-ngo'),
      '0.1' =>  esc_attr('0.1','vw-charity-ngo'),
      '0.2' =>  esc_attr('0.2','vw-charity-ngo'),
      '0.3' =>  esc_attr('0.3','vw-charity-ngo'),
      '0.4' =>  esc_attr('0.4','vw-charity-ngo'),
      '0.5' =>  esc_attr('0.5','vw-charity-ngo'),
      '0.6' =>  esc_attr('0.6','vw-charity-ngo'),
      '0.7' =>  esc_attr('0.7','vw-charity-ngo'),
      '0.8' =>  esc_attr('0.8','vw-charity-ngo'),
      '0.9' =>  esc_attr('0.9','vw-charity-ngo')
	),
	));

	//Slider height
	$wp_customize->add_setting('vw_charity_ngo_slider_height',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_charity_ngo_slider_height',array(
		'label'	=> __('Slider Height','vw-charity-ngo'),
		'description'	=> __('Specify the slider height (px).','vw-charity-ngo'),
		'input_attrs' => array(
            'placeholder' => __( '500px', 'vw-charity-ngo' ),
        ),
		'section'=> 'vw_charity_ngo_slidersettings',
		'type'=> 'text'
	));

	$wp_customize->add_setting( 'vw_charity_ngo_slider_speed', array(
		'default'  => 4000,
		'sanitize_callback'	=> 'vw_charity_ngo_sanitize_float'
	) );
	$wp_customize->add_control( 'vw_charity_ngo_slider_speed', array(
		'label' => esc_html__('Slider Transition Speed','vw-charity-ngo'),
		'section' => 'vw_charity_ngo_slidersettings',
		'type'  => 'number',
	) );

	//Scholarship
	$wp_customize->add_section( 'vw_charity_ngo_scholarship' , array(
    	'title'      => __( 'Scholarship Section', 'vw-charity-ngo' ),
		'priority'   => null,
		'panel' => 'vw_charity_ngo_panel_id'
	) );

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial( 'vw_charity_ngo_scholarship_excerpt_number', array( 
		'selector' => '.scholarship-box h2 a', 
		'render_callback' => 'vw_charity_ngo_customize_partial_vw_charity_ngo_scholarship_excerpt_number',
	));

	for ( $count = 1; $count <= 3; $count++ ) {
		// Add color scheme setting and control.
		$wp_customize->add_setting( 'vw_charity_ngo_scholarship_page' . $count, array(
			'default'           => '',
			'sanitize_callback' => 'vw_charity_ngo_sanitize_dropdown_pages'
		) );
		$wp_customize->add_control( 'vw_charity_ngo_scholarship_page' . $count, array(
			'label'    => __( 'Select Scholarship Page', 'vw-charity-ngo' ),
			'section'  => 'vw_charity_ngo_scholarship',
			'type'     => 'dropdown-pages'
		) );
	}

	//Scholarship excerpt
	$wp_customize->add_setting( 'vw_charity_ngo_scholarship_excerpt_number', array(
		'default'              => 30,
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'vw_charity_ngo_sanitize_number_range'
	) );
	$wp_customize->add_control( 'vw_charity_ngo_scholarship_excerpt_number', array(
		'label'       => esc_html__( 'Scholarship Excerpt length','vw-charity-ngo' ),
		'section'     => 'vw_charity_ngo_scholarship',
		'type'        => 'range',
		'settings'    => 'vw_charity_ngo_scholarship_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	//What We Do
	$wp_customize->add_section( 'vw_charity_ngo_what_do' , array(
    	'title'      => __( 'What we do Section', 'vw-charity-ngo' ),
		'priority'   => null,
		'panel' => 'vw_charity_ngo_panel_id'
	) );

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial( 'vw_charity_ngo_what_title', array( 
		'selector' => '#what-do h3', 
		'render_callback' => 'vw_charity_ngo_customize_partial_vw_charity_ngo_what_title',
	));

	$wp_customize->add_setting('vw_charity_ngo_what_title',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('vw_charity_ngo_what_title',array(
		'label'	=> __('Section Title','vw-charity-ngo'),
		'section'	=> 'vw_charity_ngo_what_do',
		'setting'	=> 'vw_charity_ngo_what_title',
		'type'		=> 'text'
	));

	for ( $count = 1; $count <= 3; $count++ ) {
		// Add color scheme setting and control.
		$wp_customize->add_setting( 'vw_charity_ngo_what_do_page' . $count, array(
			'default'           => '',
			'sanitize_callback' => 'vw_charity_ngo_sanitize_dropdown_pages'
		) );
		$wp_customize->add_control( 'vw_charity_ngo_what_do_page' . $count, array(
			'label'    => __( 'Select What we do Page', 'vw-charity-ngo' ),
			'section'  => 'vw_charity_ngo_what_do',
			'type'     => 'dropdown-pages'
		) );
	}

	//What We Do excerpt
	$wp_customize->add_setting( 'vw_charity_ngo_what_we_do_excerpt_number', array(
		'default'              => 30,
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'vw_charity_ngo_sanitize_number_range'
	) );
	$wp_customize->add_control( 'vw_charity_ngo_what_we_do_excerpt_number', array(
		'label'       => esc_html__( 'What We Do Excerpt length','vw-charity-ngo' ),
		'section'     => 'vw_charity_ngo_what_do',
		'type'        => 'range',
		'settings'    => 'vw_charity_ngo_what_we_do_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	//Blog Post
	$wp_customize->add_panel( $VWCharityNGOParentPanel );

	$BlogPostParentPanel = new VW_Charity_NGO_WP_Customize_Panel( $wp_customize, 'blog_post_parent_panel', array(
		'title' => __( 'Blog Post Settings', 'vw-charity-ngo' ),
		'panel' => 'vw_charity_ngo_panel_id',
	));

	$wp_customize->add_panel( $BlogPostParentPanel );

	// Add example section and controls to the middle (second) panel
	$wp_customize->add_section( 'vw_charity_ngo_post_settings', array(
		'title' => __( 'Post Settings', 'vw-charity-ngo' ),
		'panel' => 'blog_post_parent_panel',
	));	

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('vw_charity_ngo_toggle_postdate', array( 
		'selector' => '.post-main-box h2 a', 
		'render_callback' => 'vw_charity_ngo_customize_partial_vw_charity_ngo_toggle_postdate', 
	));

	$wp_customize->add_setting( 'vw_charity_ngo_toggle_postdate',array(
        'default' => 1,
        'transport' => 'refresh',
        'sanitize_callback' => 'vw_charity_ngo_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Charity_NGO_Toggle_Switch_Custom_Control( $wp_customize, 'vw_charity_ngo_toggle_postdate',array(
        'label' => esc_html__( 'Post Date','vw-charity-ngo' ),
        'section' => 'vw_charity_ngo_post_settings'
    )));

    $wp_customize->add_setting( 'vw_charity_ngo_toggle_author',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_charity_ngo_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Charity_NGO_Toggle_Switch_Custom_Control( $wp_customize, 'vw_charity_ngo_toggle_author',array(
		'label' => esc_html__( 'Author','vw-charity-ngo' ),
		'section' => 'vw_charity_ngo_post_settings'
    )));

    $wp_customize->add_setting( 'vw_charity_ngo_toggle_comments',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_charity_ngo_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Charity_NGO_Toggle_Switch_Custom_Control( $wp_customize, 'vw_charity_ngo_toggle_comments',array(
		'label' => esc_html__( 'Comments','vw-charity-ngo' ),
		'section' => 'vw_charity_ngo_post_settings'
    )));

    $wp_customize->add_setting( 'vw_charity_ngo_toggle_time',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_charity_ngo_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Charity_NGO_Toggle_Switch_Custom_Control( $wp_customize, 'vw_charity_ngo_toggle_time',array(
		'label' => esc_html__( 'Time','vw-charity-ngo' ),
		'section' => 'vw_charity_ngo_post_settings'
    )));

    $wp_customize->add_setting( 'vw_charity_ngo_featured_image_hide_show',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_charity_ngo_switch_sanitization'
	));
    $wp_customize->add_control( new VW_Charity_NGO_Toggle_Switch_Custom_Control( $wp_customize, 'vw_charity_ngo_featured_image_hide_show', array(
		'label' => esc_html__( 'Featured Image','vw-charity-ngo' ),
		'section' => 'vw_charity_ngo_post_settings'
    )));

    $wp_customize->add_setting( 'vw_charity_ngo_excerpt_number', array(
		'default'              => 30,
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'vw_charity_ngo_sanitize_number_range'
	) );
	$wp_customize->add_control( 'vw_charity_ngo_excerpt_number', array(
		'label'       => esc_html__( 'Excerpt length','vw-charity-ngo' ),
		'section'     => 'vw_charity_ngo_post_settings',
		'type'        => 'range',
		'settings'    => 'vw_charity_ngo_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	$wp_customize->add_setting('vw_charity_ngo_meta_field_separator',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_charity_ngo_meta_field_separator',array(
		'label'	=> __('Add Meta Separator','vw-charity-ngo'),
		'description' => __('Add the seperator for meta box. Example: "|", "/", etc.','vw-charity-ngo'),
		'section'=> 'vw_charity_ngo_post_settings',
		'type'=> 'text'
	));

	//Blog layout
    $wp_customize->add_setting('vw_charity_ngo_blog_layout_option',array(
        'default' => 'Default',
        'sanitize_callback' => 'vw_charity_ngo_sanitize_choices'
    ));
    $wp_customize->add_control(new VW_Charity_NGO_Image_Radio_Control($wp_customize, 'vw_charity_ngo_blog_layout_option', array(
        'type' => 'select',
        'label' => __('Blog Layouts','vw-charity-ngo'),
        'section' => 'vw_charity_ngo_post_settings',
        'choices' => array(
            'Default' => esc_url(get_template_directory_uri()).'/images/blog-layout1.png',
            'Center' => esc_url(get_template_directory_uri()).'/images/blog-layout2.png',
            'Left' => esc_url(get_template_directory_uri()).'/images/blog-layout3.png',
    ))));

    $wp_customize->add_setting('vw_charity_ngo_excerpt_settings',array(
        'default' => 'Excerpt',
        'transport' => 'refresh',
        'sanitize_callback' => 'vw_charity_ngo_sanitize_choices'
	));
	$wp_customize->add_control('vw_charity_ngo_excerpt_settings',array(
        'type' => 'select',
        'label' => __('Post Content','vw-charity-ngo'),
        'section' => 'vw_charity_ngo_post_settings',
        'choices' => array(
        	'Content' => __('Content','vw-charity-ngo'),
            'Excerpt' => __('Excerpt','vw-charity-ngo'),
            'No Content' => __('No Content','vw-charity-ngo')
        ),
	) );

	$wp_customize->add_setting('vw_charity_ngo_excerpt_suffix',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_charity_ngo_excerpt_suffix',array(
		'label'	=> __('Add Excerpt Suffix','vw-charity-ngo'),
		'input_attrs' => array(
            'placeholder' => __( '[...]', 'vw-charity-ngo' ),
        ),
		'section'=> 'vw_charity_ngo_post_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting( 'vw_charity_ngo_blog_pagination_hide_show',array(
      'default' => 1,
      'transport' => 'refresh',
      'sanitize_callback' => 'vw_charity_ngo_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Charity_NGO_Toggle_Switch_Custom_Control( $wp_customize, 'vw_charity_ngo_blog_pagination_hide_show',array(
      'label' => esc_html__( 'Show / Hide Blog Pagination','vw-charity-ngo' ),
      'section' => 'vw_charity_ngo_post_settings'
    )));

	$wp_customize->add_setting( 'vw_charity_ngo_blog_pagination_type', array(
        'default'			=> 'blog-page-numbers',
        'sanitize_callback'	=> 'vw_charity_ngo_sanitize_choices'
    ));
    $wp_customize->add_control( 'vw_charity_ngo_blog_pagination_type', array(
        'section' => 'vw_charity_ngo_post_settings',
        'type' => 'select',
        'label' => __( 'Blog Pagination', 'vw-charity-ngo' ),
        'choices'		=> array(
            'blog-page-numbers'  => __( 'Numeric', 'vw-charity-ngo' ),
            'next-prev' => __( 'Older Posts/Newer Posts', 'vw-charity-ngo' ),
    )));

    // Button Settings
	$wp_customize->add_section( 'vw_charity_ngo_button_settings', array(
		'title' => __( 'Button Settings', 'vw-charity-ngo' ),
		'panel' => 'blog_post_parent_panel',
	));

	$wp_customize->add_setting('vw_charity_ngo_button_padding_top_bottom',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_charity_ngo_button_padding_top_bottom',array(
		'label'	=> __('Padding Top Bottom','vw-charity-ngo'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-charity-ngo'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-charity-ngo' ),
        ),
		'section'=> 'vw_charity_ngo_button_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_charity_ngo_button_padding_left_right',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_charity_ngo_button_padding_left_right',array(
		'label'	=> __('Padding Left Right','vw-charity-ngo'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-charity-ngo'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-charity-ngo' ),
        ),
		'section'=> 'vw_charity_ngo_button_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting( 'vw_charity_ngo_button_border_radius', array(
		'default'              => '',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'vw_charity_ngo_sanitize_number_range'
	) );
	$wp_customize->add_control( 'vw_charity_ngo_button_border_radius', array(
		'label'       => esc_html__( 'Button Border Radius','vw-charity-ngo' ),
		'section'     => 'vw_charity_ngo_button_settings',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('vw_charity_ngo_button_text', array( 
		'selector' => '.post-main-box .content-bttn a', 
		'render_callback' => 'vw_charity_ngo_customize_partial_vw_charity_ngo_button_text', 
	));

    $wp_customize->add_setting('vw_charity_ngo_button_text',array(
		'default'=> esc_html__( 'Read More', 'vw-charity-ngo' ),
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_charity_ngo_button_text',array(
		'label'	=> __('Add Button Text','vw-charity-ngo'),
		'input_attrs' => array(
            'placeholder' => __( 'Read More', 'vw-charity-ngo' ),
        ),
		'section'=> 'vw_charity_ngo_button_settings',
		'type'=> 'text'
	));

	// Related Post Settings
	$wp_customize->add_section( 'vw_charity_ngo_related_posts_settings', array(
		'title' => __( 'Related Posts Settings', 'vw-charity-ngo' ),
		'panel' => 'blog_post_parent_panel',
	));

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('vw_charity_ngo_related_post_title', array( 
		'selector' => '.related-post h3', 
		'render_callback' => 'vw_charity_ngo_customize_partial_vw_charity_ngo_related_post_title', 
	));

    $wp_customize->add_setting( 'vw_charity_ngo_related_post',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_charity_ngo_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Charity_NGO_Toggle_Switch_Custom_Control( $wp_customize, 'vw_charity_ngo_related_post',array(
		'label' => esc_html__( 'Related Post','vw-charity-ngo' ),
		'section' => 'vw_charity_ngo_related_posts_settings'
    )));

    $wp_customize->add_setting('vw_charity_ngo_related_post_title',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_charity_ngo_related_post_title',array(
		'label'	=> __('Add Related Post Title','vw-charity-ngo'),
		'input_attrs' => array(
            'placeholder' => __( 'Related Post', 'vw-charity-ngo' ),
        ),
		'section'=> 'vw_charity_ngo_related_posts_settings',
		'type'=> 'text'
	));

   	$wp_customize->add_setting('vw_charity_ngo_related_posts_count',array(
		'default'=> '3',
		'sanitize_callback'	=> 'vw_charity_ngo_sanitize_float'
	));
	$wp_customize->add_control('vw_charity_ngo_related_posts_count',array(
		'label'	=> __('Add Related Post Count','vw-charity-ngo'),
		'input_attrs' => array(
            'placeholder' => __( '3', 'vw-charity-ngo' ),
        ),
		'section'=> 'vw_charity_ngo_related_posts_settings',
		'type'=> 'number'
	));

	// Single Posts Settings
	$wp_customize->add_section( 'vw_charity_ngo_single_blog_settings', array(
		'title' => __( 'Single Post Settings', 'vw-charity-ngo' ),
		'panel' => 'blog_post_parent_panel',
	));

	 $wp_customize->add_setting( 'vw_charity_ngo_toggle_tags',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_charity_ngo_switch_sanitization'
	));
    $wp_customize->add_control( new VW_Charity_NGO_Toggle_Switch_Custom_Control( $wp_customize, 'vw_charity_ngo_toggle_tags', array(
		'label' => esc_html__( 'Tags','vw-charity-ngo' ),
		'section' => 'vw_charity_ngo_single_blog_settings'
    )));

	$wp_customize->add_setting( 'vw_charity_ngo_single_blog_post_navigation_show_hide',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_charity_ngo_switch_sanitization'
	));
    $wp_customize->add_control( new VW_Charity_NGO_Toggle_Switch_Custom_Control( $wp_customize, 'vw_charity_ngo_single_blog_post_navigation_show_hide', array(
		'label' => esc_html__( 'Post Navigation','vw-charity-ngo' ),
		'section' => 'vw_charity_ngo_single_blog_settings'
    )));

	//navigation text
	$wp_customize->add_setting('vw_charity_ngo_single_blog_prev_navigation_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_charity_ngo_single_blog_prev_navigation_text',array(
		'label'	=> __('Post Navigation Text','vw-charity-ngo'),
		'input_attrs' => array(
            'placeholder' => __( 'PREVIOUS', 'vw-charity-ngo' ),
        ),
		'section'=> 'vw_charity_ngo_single_blog_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_charity_ngo_single_blog_next_navigation_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_charity_ngo_single_blog_next_navigation_text',array(
		'label'	=> __('Post Navigation Text','vw-charity-ngo'),
		'input_attrs' => array(
            'placeholder' => __( 'NEXT', 'vw-charity-ngo' ),
        ),
		'section'=> 'vw_charity_ngo_single_blog_settings',
		'type'=> 'text'
	));

    //404 Page Setting
	$wp_customize->add_section('vw_charity_ngo_404_page',array(
		'title'	=> __('404 Page Settings','vw-charity-ngo'),
		'panel' => 'vw_charity_ngo_panel_id',
	));	

	$wp_customize->add_setting('vw_charity_ngo_404_page_title',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('vw_charity_ngo_404_page_title',array(
		'label'	=> __('Add Title','vw-charity-ngo'),
		'input_attrs' => array(
            'placeholder' => __( '404 Not Found', 'vw-charity-ngo' ),
        ),
		'section'=> 'vw_charity_ngo_404_page',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_charity_ngo_404_page_content',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('vw_charity_ngo_404_page_content',array(
		'label'	=> __('Add Text','vw-charity-ngo'),
		'input_attrs' => array(
            'placeholder' => __( 'Looks like you have taken a wrong turn, Dont worry, it happens to the best of us.', 'vw-charity-ngo' ),
        ),
		'section'=> 'vw_charity_ngo_404_page',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_charity_ngo_404_page_button_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_charity_ngo_404_page_button_text',array(
		'label'	=> __('Add Button Text','vw-charity-ngo'),
		'input_attrs' => array(
            'placeholder' => __( 'Return to the home page', 'vw-charity-ngo' ),
        ),
		'section'=> 'vw_charity_ngo_404_page',
		'type'=> 'text'
	));

	//Social Icon Setting
	$wp_customize->add_section('vw_charity_ngo_social_icon_settings',array(
		'title'	=> __('Social Icons Settings','vw-charity-ngo'),
		'panel' => 'vw_charity_ngo_panel_id',
	));	

	$wp_customize->add_setting('vw_charity_ngo_social_icon_font_size',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_charity_ngo_social_icon_font_size',array(
		'label'	=> __('Icon Font Size','vw-charity-ngo'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-charity-ngo'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-charity-ngo' ),
        ),
		'section'=> 'vw_charity_ngo_social_icon_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_charity_ngo_social_icon_padding',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_charity_ngo_social_icon_padding',array(
		'label'	=> __('Icon Padding','vw-charity-ngo'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-charity-ngo'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-charity-ngo' ),
        ),
		'section'=> 'vw_charity_ngo_social_icon_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_charity_ngo_social_icon_width',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_charity_ngo_social_icon_width',array(
		'label'	=> __('Icon Width','vw-charity-ngo'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-charity-ngo'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-charity-ngo' ),
        ),
		'section'=> 'vw_charity_ngo_social_icon_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_charity_ngo_social_icon_height',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_charity_ngo_social_icon_height',array(
		'label'	=> __('Icon Height','vw-charity-ngo'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-charity-ngo'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-charity-ngo' ),
        ),
		'section'=> 'vw_charity_ngo_social_icon_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting( 'vw_charity_ngo_social_icon_border_radius', array(
		'default'              => '',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'vw_charity_ngo_sanitize_number_range'
	) );
	$wp_customize->add_control( 'vw_charity_ngo_social_icon_border_radius', array(
		'label'       => esc_html__( 'Icon Border Radius','vw-charity-ngo' ),
		'section'     => 'vw_charity_ngo_social_icon_settings',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	//Responsive Media Settings
	$wp_customize->add_section('vw_charity_ngo_responsive_media',array(
		'title'	=> __('Responsive Media','vw-charity-ngo'),
		'panel' => 'vw_charity_ngo_panel_id',
	));

	$wp_customize->add_setting( 'vw_charity_ngo_resp_topbar_hide_show',array(
      'default' => 0,
      'transport' => 'refresh',
      'sanitize_callback' => 'vw_charity_ngo_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Charity_NGO_Toggle_Switch_Custom_Control( $wp_customize, 'vw_charity_ngo_resp_topbar_hide_show',array(
      'label' => esc_html__( 'Show / Hide Topbar','vw-charity-ngo' ),
      'section' => 'vw_charity_ngo_responsive_media'
    )));

    $wp_customize->add_setting( 'vw_charity_ngo_stickyheader_hide_show',array(
      'default' => 0,
      'transport' => 'refresh',
      'sanitize_callback' => 'vw_charity_ngo_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Charity_NGO_Toggle_Switch_Custom_Control( $wp_customize, 'vw_charity_ngo_stickyheader_hide_show',array(
      'label' => esc_html__( 'Sticky Header','vw-charity-ngo' ),
      'section' => 'vw_charity_ngo_responsive_media'
    )));

    $wp_customize->add_setting( 'vw_charity_ngo_resp_slider_hide_show',array(
      'default' => 0,
      'transport' => 'refresh',
      'sanitize_callback' => 'vw_charity_ngo_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Charity_NGO_Toggle_Switch_Custom_Control( $wp_customize, 'vw_charity_ngo_resp_slider_hide_show',array(
      'label' => esc_html__( 'Show / Hide Slider','vw-charity-ngo' ),
      'section' => 'vw_charity_ngo_responsive_media'
    )));

    $wp_customize->add_setting( 'vw_charity_ngo_sidebar_hide_show',array(
      'default' => 1,
      'transport' => 'refresh',
      'sanitize_callback' => 'vw_charity_ngo_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Charity_NGO_Toggle_Switch_Custom_Control( $wp_customize, 'vw_charity_ngo_sidebar_hide_show',array(
      'label' => esc_html__( 'Show / Hide Sidebar','vw-charity-ngo' ),
      'section' => 'vw_charity_ngo_responsive_media'
    )));

    $wp_customize->add_setting( 'vw_charity_ngo_resp_scroll_top_hide_show',array(
      'default' => 1,
      'transport' => 'refresh',
      'sanitize_callback' => 'vw_charity_ngo_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Charity_NGO_Toggle_Switch_Custom_Control( $wp_customize, 'vw_charity_ngo_resp_scroll_top_hide_show',array(
      'label' => esc_html__( 'Show / Hide Scroll To Top','vw-charity-ngo' ),
      'section' => 'vw_charity_ngo_responsive_media'
    )));

    $wp_customize->add_setting('vw_charity_ngo_res_menu_open_icon',array(
		'default'	=> 'fas fa-bars',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new VW_Charity_NGO_Fontawesome_Icon_Chooser(
        $wp_customize,'vw_charity_ngo_res_menu_open_icon',array(
		'label'	=> __('Add Open Menu Icon','vw-charity-ngo'),
		'transport' => 'refresh',
		'section'	=> 'vw_charity_ngo_responsive_media',
		'setting'	=> 'vw_charity_ngo_res_menu_open_icon',
		'type'		=> 'icon'
	)));

	$wp_customize->add_setting('vw_charity_ngo_res_menu_close_icon',array(
		'default'	=> 'fas fa-times',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new VW_Charity_NGO_Fontawesome_Icon_Chooser(
        $wp_customize,'vw_charity_ngo_res_menu_close_icon',array(
		'label'	=> __('Add Close Menu Icon','vw-charity-ngo'),
		'transport' => 'refresh',
		'section'	=> 'vw_charity_ngo_responsive_media',
		'setting'	=> 'vw_charity_ngo_res_menu_close_icon',
		'type'		=> 'icon'
	)));

	//Footer Text
	$wp_customize->add_section('vw_charity_ngo_footer',array(
		'title'	=> __('Footer','vw-charity-ngo'),
		'description'=> __('This section will appear in the footer','vw-charity-ngo'),
		'panel' => 'vw_charity_ngo_panel_id',
	));	

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('vw_charity_ngo_footer_text', array( 
		'selector' => '.footer-2 .copyright p', 
		'render_callback' => 'vw_charity_ngo_customize_partial_vw_charity_ngo_footer_text', 
	));
	
	$wp_customize->add_setting('vw_charity_ngo_footer_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('vw_charity_ngo_footer_text',array(
		'label'	=> __('Copyright Text','vw-charity-ngo'),
		'section'=> 'vw_charity_ngo_footer',
		'setting'=> 'vw_charity_ngo_footer_text',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_charity_ngo_copyright_alingment',array(
        'default' => 'center',
        'sanitize_callback' => 'vw_charity_ngo_sanitize_choices'
	));
	$wp_customize->add_control(new VW_Charity_NGO_Image_Radio_Control($wp_customize, 'vw_charity_ngo_copyright_alingment', array(
        'type' => 'select',
        'label' => __('Copyright Alignment','vw-charity-ngo'),
        'section' => 'vw_charity_ngo_footer',
        'settings' => 'vw_charity_ngo_copyright_alingment',
        'choices' => array(
            'left' => esc_url(get_template_directory_uri()).'/images/copyright1.png',
            'center' => esc_url(get_template_directory_uri()).'/images/copyright2.png',
            'right' => esc_url(get_template_directory_uri()).'/images/copyright3.png'
    ))));

    $wp_customize->add_setting('vw_charity_ngo_copyright_padding_top_bottom',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_charity_ngo_copyright_padding_top_bottom',array(
		'label'	=> __('Copyright Padding Top Bottom','vw-charity-ngo'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-charity-ngo'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-charity-ngo' ),
        ),
		'section'=> 'vw_charity_ngo_footer',
		'type'=> 'text'
	));

	$wp_customize->add_setting( 'vw_charity_ngo_hide_show_scroll',array(
    	'default' => 1,
      	'transport' => 'refresh',
      	'sanitize_callback' => 'vw_charity_ngo_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Charity_NGO_Toggle_Switch_Custom_Control( $wp_customize, 'vw_charity_ngo_hide_show_scroll',array(
      	'label' => esc_html__( 'Show / Hide Scroll To Top','vw-charity-ngo' ),
      	'section' => 'vw_charity_ngo_footer'
    )));

    //Selective Refresh
	$wp_customize->selective_refresh->add_partial('vw_charity_ngo_scroll_to_top_icon', array( 
		'selector' => '.scrollup i', 
		'render_callback' => 'vw_charity_ngo_customize_partial_vw_charity_ngo_scroll_to_top_icon', 
	));

    $wp_customize->add_setting('vw_charity_ngo_scroll_to_top_icon',array(
		'default'	=> 'fas fa-long-arrow-alt-up',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control(new VW_Charity_NGO_Fontawesome_Icon_Chooser(
        $wp_customize,'vw_charity_ngo_scroll_to_top_icon',array(
		'label'	=> __('Add Scroll to Top Icon','vw-charity-ngo'),
		'transport' => 'refresh',
		'section'	=> 'vw_charity_ngo_footer',
		'setting'	=> 'vw_charity_ngo_scroll_to_top_icon',
		'type'		=> 'icon'
	)));	

	$wp_customize->add_setting('vw_charity_ngo_scroll_to_top_font_size',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_charity_ngo_scroll_to_top_font_size',array(
		'label'	=> __('Icon Font Size','vw-charity-ngo'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-charity-ngo'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-charity-ngo' ),
        ),
		'section'=> 'vw_charity_ngo_footer',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_charity_ngo_scroll_to_top_padding',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_charity_ngo_scroll_to_top_padding',array(
		'label'	=> __('Icon Top Bottom Padding','vw-charity-ngo'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-charity-ngo'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-charity-ngo' ),
        ),
		'section'=> 'vw_charity_ngo_footer',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_charity_ngo_scroll_to_top_width',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_charity_ngo_scroll_to_top_width',array(
		'label'	=> __('Icon Width','vw-charity-ngo'),
		'description'	=> __('Enter a value in pixels Example:20px','vw-charity-ngo'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-charity-ngo' ),
        ),
		'section'=> 'vw_charity_ngo_footer',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_charity_ngo_scroll_to_top_height',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_charity_ngo_scroll_to_top_height',array(
		'label'	=> __('Icon Height','vw-charity-ngo'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-charity-ngo'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-charity-ngo' ),
        ),
		'section'=> 'vw_charity_ngo_footer',
		'type'=> 'text'
	));

	$wp_customize->add_setting( 'vw_charity_ngo_scroll_to_top_border_radius', array(
		'default'              => '',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'vw_charity_ngo_sanitize_number_range'
	) );
	$wp_customize->add_control( 'vw_charity_ngo_scroll_to_top_border_radius', array(
		'label'       => esc_html__( 'Icon Border Radius','vw-charity-ngo' ),
		'section'     => 'vw_charity_ngo_footer',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	$wp_customize->add_setting('vw_charity_ngo_scroll_top_alignment',array(
        'default' => 'Right',
        'sanitize_callback' => 'vw_charity_ngo_sanitize_choices'
	));
	$wp_customize->add_control(new VW_Charity_NGO_Image_Radio_Control($wp_customize, 'vw_charity_ngo_scroll_top_alignment', array(
        'type' => 'select',
        'label' => __('Scroll To Top','vw-charity-ngo'),
        'section' => 'vw_charity_ngo_footer',
        'settings' => 'vw_charity_ngo_scroll_top_alignment',
        'choices' => array(
            'Left' => esc_url(get_template_directory_uri()).'/images/layout1.png',
            'Center' => esc_url(get_template_directory_uri()).'/images/layout2.png',
            'Right' => esc_url(get_template_directory_uri()).'/images/layout3.png'
    ))));

    //Woocommerce settings
	$wp_customize->add_section('vw_charity_ngo_woocommerce_section', array(
		'title'    => __('WooCommerce Layout', 'vw-charity-ngo'),
		'priority' => null,
		'panel'    => 'woocommerce',
	));

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial( 'vw_charity_ngo_woocommerce_shop_page_sidebar', array( 'selector' => '.post-type-archive-product .sidebar', 
		'render_callback' => 'vw_charity_ngo_customize_partial_vw_charity_ngo_woocommerce_shop_page_sidebar', ) );

    //Woocommerce Shop Page Sidebar
	$wp_customize->add_setting( 'vw_charity_ngo_woocommerce_shop_page_sidebar',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_charity_ngo_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Charity_NGO_Toggle_Switch_Custom_Control( $wp_customize, 'vw_charity_ngo_woocommerce_shop_page_sidebar',array(
		'label' => esc_html__( 'Shop Page Sidebar','vw-charity-ngo' ),
		'section' => 'vw_charity_ngo_woocommerce_section'
    )));

     //Selective Refresh
	$wp_customize->selective_refresh->add_partial( 'vw_charity_ngo_woocommerce_single_product_page_sidebar', array( 'selector' => '.single-product .sidebar', 
		'render_callback' => 'vw_charity_ngo_customize_partial_vw_charity_ngo_woocommerce_single_product_page_sidebar', ) );

    //Woocommerce Single Product page Sidebar
	$wp_customize->add_setting( 'vw_charity_ngo_woocommerce_single_product_page_sidebar',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_charity_ngo_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Charity_NGO_Toggle_Switch_Custom_Control( $wp_customize, 'vw_charity_ngo_woocommerce_single_product_page_sidebar',array(
		'label' => esc_html__( 'Single Product Sidebar','vw-charity-ngo' ),
		'section' => 'vw_charity_ngo_woocommerce_section'
    )));

     //Products per page
    $wp_customize->add_setting('vw_charity_ngo_products_per_page',array(
		'default'=> '9',
		'sanitize_callback'	=> 'vw_charity_ngo_sanitize_float'
	));
	$wp_customize->add_control('vw_charity_ngo_products_per_page',array(
		'label'	=> __('Products Per Page','vw-charity-ngo'),
		'description' => __('Display on shop page','vw-charity-ngo'),
		'input_attrs' => array(
            'step'             => 1,
			'min'              => 0,
			'max'              => 50,
        ),
		'section'=> 'vw_charity_ngo_woocommerce_section',
		'type'=> 'number',
	));

    //Products per row
    $wp_customize->add_setting('vw_charity_ngo_products_per_row',array(
		'default'=> '3',
		'sanitize_callback'	=> 'vw_charity_ngo_sanitize_choices'
	));
	$wp_customize->add_control('vw_charity_ngo_products_per_row',array(
		'label'	=> __('Products Per Row','vw-charity-ngo'),
		'description' => __('Display on shop page','vw-charity-ngo'),
		'choices' => array(
            '2' => '2',
			'3' => '3',
			'4' => '4',
        ),
		'section'=> 'vw_charity_ngo_woocommerce_section',
		'type'=> 'select',
	));

	//Products padding
	$wp_customize->add_setting('vw_charity_ngo_products_padding_top_bottom',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_charity_ngo_products_padding_top_bottom',array(
		'label'	=> __('Products Padding Top Bottom','vw-charity-ngo'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-charity-ngo'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-charity-ngo' ),
        ),
		'section'=> 'vw_charity_ngo_woocommerce_section',
		'type'=> 'text'
	));

	$wp_customize->add_setting('vw_charity_ngo_products_padding_left_right',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_charity_ngo_products_padding_left_right',array(
		'label'	=> __('Products Padding Left Right','vw-charity-ngo'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-charity-ngo'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-charity-ngo' ),
        ),
		'section'=> 'vw_charity_ngo_woocommerce_section',
		'type'=> 'text'
	));

	//Products box shadow
	$wp_customize->add_setting( 'vw_charity_ngo_products_box_shadow', array(
		'default'              => '',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'vw_charity_ngo_sanitize_number_range'
	) );
	$wp_customize->add_control( 'vw_charity_ngo_products_box_shadow', array(
		'label'       => esc_html__( 'Products Box Shadow','vw-charity-ngo' ),
		'section'     => 'vw_charity_ngo_woocommerce_section',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	//Products border radius
    $wp_customize->add_setting( 'vw_charity_ngo_products_border_radius', array(
		'default'              => '0',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'vw_charity_ngo_sanitize_number_range'
	) );
	$wp_customize->add_control( 'vw_charity_ngo_products_border_radius', array(
		'label'       => esc_html__( 'Products Border Radius','vw-charity-ngo' ),
		'section'     => 'vw_charity_ngo_woocommerce_section',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	$wp_customize->add_setting( 'vw_charity_ngo_products_button_border_radius', array(
		'default'           => 0,
		'transport' 	    => 'refresh',
		'sanitize_callback' => 'vw_charity_ngo_sanitize_number_range'
	) );
	$wp_customize->add_control( 'vw_charity_ngo_products_button_border_radius', array(
		'label'       => esc_html__( 'Products Button Border Radius','vw-charity-ngo' ),
		'section'    => 'vw_charity_ngo_woocommerce_section',
		'type'        => 'range',
		'input_attrs' => array(
			'step' => 1,
			'min'  => 1,
			'max'  => 50,
		),
	) );

	$wp_customize->add_setting('vw_charity_ngo_woocommerce_sale_font_size',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('vw_charity_ngo_woocommerce_sale_font_size',array(
		'label'	=> __('Sale Font Size','vw-charity-ngo'),
		'description'	=> __('Enter a value in pixels. Example:20px','vw-charity-ngo'),
		'input_attrs' => array(
            'placeholder' => __( '10px', 'vw-charity-ngo' ),
        ),
		'section'=> 'vw_charity_ngo_woocommerce_section',
		'type'=> 'text'
	));

	$wp_customize->add_setting( 'vw_charity_ngo_woocommerce_sale_border_radius', array(
		'default'              => '100',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'vw_charity_ngo_sanitize_number_range'
	) );
	$wp_customize->add_control( 'vw_charity_ngo_woocommerce_sale_border_radius', array(
		'label'       => esc_html__( 'Sale Border Radius','vw-charity-ngo' ),
		'section'     => 'vw_charity_ngo_woocommerce_section',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

    // Has to be at the top
	$wp_customize->register_panel_type( 'VW_Charity_NGO_WP_Customize_Panel' );
	$wp_customize->register_section_type( 'VW_Charity_NGO_WP_Customize_Section' );
}

add_action( 'customize_register', 'vw_charity_ngo_customize_register' );

load_template( trailingslashit( get_template_directory() ) . '/inc/logo/logo-resizer.php' );

if ( class_exists( 'WP_Customize_Panel' ) ) {
  	class VW_Charity_NGO_WP_Customize_Panel extends WP_Customize_Panel {
	    public $panel;
	    public $type = 'vw_charity_ngo_panel';
	    public function json() {

	      $array = wp_array_slice_assoc( (array) $this, array( 'id', 'description', 'priority', 'type', 'panel', ) );
	      $array['title'] = html_entity_decode( $this->title, ENT_QUOTES, get_bloginfo( 'charset' ) );
	      $array['content'] = $this->get_content();
	      $array['active'] = $this->active();
	      $array['instanceNumber'] = $this->instance_number;
	      return $array;
    	}
 	}
}

if ( class_exists( 'WP_Customize_Section' ) ) {
  	class VW_Charity_NGO_WP_Customize_Section extends WP_Customize_Section {
	    public $section;
	    public $type = 'vw_charity_ngo_section';
	    public function json() {

	      $array = wp_array_slice_assoc( (array) $this, array( 'id', 'description', 'priority', 'panel', 'type', 'description_hidden', 'section', ) );
	      $array['title'] = html_entity_decode( $this->title, ENT_QUOTES, get_bloginfo( 'charset' ) );
	      $array['content'] = $this->get_content();
	      $array['active'] = $this->active();
	      $array['instanceNumber'] = $this->instance_number;

	      if ( $this->panel ) {
	        $array['customizeAction'] = sprintf( 'Customizing &#9656; %s', esc_html( $this->manager->get_panel( $this->panel )->title ) );
	      } else {
	        $array['customizeAction'] = 'Customizing';
	      }
	      return $array;
    	}
  	}
}

// Enqueue our scripts and styles
function vw_charity_ngo_customize_controls_scripts() {
  wp_enqueue_script( 'customizer-controls', get_theme_file_uri( '/js/customizer-controls.js' ), array(), '1.0', true );
}
add_action( 'customize_controls_enqueue_scripts', 'vw_charity_ngo_customize_controls_scripts' );

/**
 * Singleton class for handling the theme's customizer integration.
 *
 * @since  1.0.0
 * @access public
 */
final class VW_Charity_Ngo_Customize {

	/**
	 * Returns the instance.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return object
	 */
	public static function get_instance() {

		static $instance = null;

		if ( is_null( $instance ) ) {
			$instance = new self;
			$instance->setup_actions();
		}

		return $instance;
	}

	/**
	 * Constructor method.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function __construct() {}

	/**
	 * Sets up initial actions.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function setup_actions() {

		// Register panels, sections, settings, controls, and partials.
		add_action( 'customize_register', array( $this, 'sections' ) );

		// Register scripts and styles for the controls.
		add_action( 'customize_controls_enqueue_scripts', array( $this, 'enqueue_control_scripts' ), 0 );
	}

	/**
	 * Sets up the customizer sections.
	 *
	 * @since  1.0.0
	 * @access public
	 * @param  object  $manager
	 * @return void
	 */
	public function sections( $manager ) {

		// Load custom sections.
		load_template( trailingslashit( get_template_directory() ) . '/inc/section-pro.php' );

		// Register custom section types.
		$manager->register_section_type( 'VW_Charity_NGO_Customize_Section_Pro' );

		// Register sections.
		$manager->add_section( new VW_Charity_NGO_Customize_Section_Pro($manager,'vw_charity_ngo_upgrade_pro_link',array(
			'priority'   => 1,
			'title'    => esc_html__( 'VW Charity NGO Pro', 'vw-charity-ngo' ),
			'pro_text' => esc_html__( 'Upgrade Pro', 'vw-charity-ngo' ),
			'pro_url'  => esc_url('https://www.vwthemes.com/themes/premium-charity-wordpress-theme/'),
		)));

		$manager->add_section(new VW_Charity_NGO_Customize_Section_Pro($manager,'vw_charity_ngo_get_started_link',array(
			'priority'   => 1,
			'title'    => esc_html__( 'Documentation', 'vw-charity-ngo' ),
			'pro_text' => esc_html__( 'Docs', 'vw-charity-ngo' ),
			'pro_url'  => admin_url( 'themes.php?page=vw_charity_ngo_guide' ),
		)));
	}

	/**
	 * Loads theme customizer CSS.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return void
	 */
	public function enqueue_control_scripts() {

		wp_enqueue_script( 'vw-charity-ngo-customize-controls', trailingslashit( esc_url(get_template_directory_uri()) ) . '/js/customize-controls.js', array( 'customize-controls' ) );

		wp_enqueue_style( 'vw-charity-ngo-customize-controls', trailingslashit( esc_url(get_template_directory_uri()) ) . '/css/customize-controls.css' );
	}
}

// Doing this customizer thang!
VW_Charity_Ngo_Customize::get_instance();